@@ -109,10 +109,7 @@ def parse_audio_playlist(
     section_list = nav(response, [*TWO_COLUMN_RENDERER, "secondaryContents", *SECTION])
     content_data = nav(section_list, [*CONTENT, "musicPlaylistShelfRenderer"])
 
-    playlist["id"] = nav(
-        content_data, [*CONTENT, MRLIR, *PLAY_BUTTON, "playNavigationEndpoint", *WATCH_PLAYLIST_ID]
-    )
-    playlist["trackCount"] = nav(content_data, ["collapsedItemCount"])
+    playlist["id"] = nav(content_data, ["targetId"])
 
     playlist["tracks"] = []
     if "contents" in content_data:
@@ -121,6 +118,8 @@ def parse_audio_playlist(
         parse_func: ParseFuncType = lambda contents: parse_playlist_items(contents)
         playlist["tracks"].extend(get_continuations_2025(content_data, limit, request_func, parse_func))
 
+    playlist["trackCount"] = len(playlist["tracks"])
+
     playlist["title"] = playlist["tracks"][0]["album"]["name"]
 
     playlist["duration_seconds"] = sum_total_duration(playlist)
@@ -220,7 +219,7 @@ def parse_playlist_item(
             # MUSIC_PAGE_TYPE_ARTIST for regular songs, MUSIC_PAGE_TYPE_UNKNOWN for uploads
             if page_type == "MUSIC_PAGE_TYPE_ARTIST" or page_type == "MUSIC_PAGE_TYPE_UNKNOWN":
                 artist_index = index
-            elif page_type == "MUSIC_PAGE_TYPE_ALBUM":
+            elif page_type in ["MUSIC_PAGE_TYPE_ALBUM", "MUSIC_PAGE_TYPE_AUDIOBOOK"]:
                 album_index = index
             elif page_type == "MUSIC_PAGE_TYPE_USER_CHANNEL":
                 user_channel_indexes.append(index)
